# NEMSpy
### Python wrapper for the NOAA Environmental Modeling System

[![tests](https://github.com/noaa-ocs-modeling/NEMSpy/workflows/tests/badge.svg)](https://github.com/noaa-ocs-modeling/NEMSpy/actions)

This repository implements the [National Unified Operational Prediction Capability (NUOPC)](https://www.earthsystemcog.org/projects/nuopc/).

#### Related Repositories:
- https://github.com/NOAA-EMC/NEMS
- https://github.com/esmf-org/esmf
